[gnome-software] Use correct grammar when notifying OS updates have been installed.



commit 9884e803efa70a5d89ba290f738f39a8cb81293e
Author: Robert Ancell <robert ancell canonical com>
Date:   Thu Sep 29 15:43:30 2016 +1300

    Use correct grammar when notifying OS updates have been installed.
    
    Fixes: https://bugzilla.gnome.org/show_bug.cgi?id=767634

 src/gs-common.c |   12 +++++++++---
 1 files changed, 9 insertions(+), 3 deletions(-)
---
diff --git a/src/gs-common.c b/src/gs-common.c
index c297a91..f844442 100644
--- a/src/gs-common.c
+++ b/src/gs-common.c
@@ -132,9 +132,15 @@ gs_app_notify_installed (GsApp *app)
        g_autofree gchar *summary = NULL;
        g_autoptr(GNotification) n = NULL;
 
-       /* TRANSLATORS: this is the summary of a notification that an application
-        * has been successfully installed */
-       summary = g_strdup_printf (_("%s is now installed"), gs_app_get_name (app));
+       if (gs_app_get_kind (app) == AS_APP_KIND_OS_UPDATE) {
+               /* TRANSLATORS: this is the summary of a notification that OS updates
+                * have been successfully installed */
+               summary = g_strdup (_("OS updates are now installed"));
+       } else {
+               /* TRANSLATORS: this is the summary of a notification that an application
+                * has been successfully installed */
+               summary = g_strdup_printf (_("%s is now installed"), gs_app_get_name (app));
+       }
        n = g_notification_new (summary);
        if (gs_app_get_kind (app) == AS_APP_KIND_DESKTOP) {
                /* TRANSLATORS: this is button that opens the newly installed application */


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]